Index: uspace/srv/devman/main.c
===================================================================
--- uspace/srv/devman/main.c	(revision 9934f7d3082d2ffdd107cc0c78d61d504b0f401e)
+++ uspace/srv/devman/main.c	(revision 86ffa27f45682aa2a5736f665f400ad262ce5baf)
@@ -56,5 +56,5 @@
 #include <ipc/driver.h>
 #include <thread.h>
-#include <devmap.h>
+#include <loc.h>
 
 #include "devman.h"
@@ -326,5 +326,5 @@
 		}
 	} else {
-		devmap_register_tree_function(fun, tree);
+		loc_register_tree_function(fun, tree);
 	}
 	
@@ -333,28 +333,28 @@
 }
 
-static void devmap_register_class_dev(dev_class_info_t *cli)
-{
-	/* Create devmap path and name for the device. */
-	char *devmap_pathname = NULL;
-
-	asprintf(&devmap_pathname, "%s/%s%c%s", DEVMAP_CLASS_NAMESPACE,
-	    cli->dev_class->name, DEVMAP_SEPARATOR, cli->dev_name);
-	if (devmap_pathname == NULL)
+static void loc_register_class_dev(dev_class_info_t *cli)
+{
+	/* Create loc path and name for the service. */
+	char *loc_pathname = NULL;
+
+	asprintf(&loc_pathname, "%s/%s%c%s", LOC_CLASS_NAMESPACE,
+	    cli->dev_class->name, LOC_SEPARATOR, cli->dev_name);
+	if (loc_pathname == NULL)
 		return;
 	
 	/*
 	 * Register the device by the device mapper and remember its devmap
 	 * handle.
 	 */
-	devmap_device_register_with_iface(devmap_pathname,
-	    &cli->devmap_handle, DEVMAN_CONNECT_FROM_DEVMAP);
+	loc_service_register_with_iface(loc_pathname,
+	    &cli->service_id, DEVMAN_CONNECT_FROM_LOC);
 	
 	/*
 	 * Add device to the hash map of class devices registered by device
 	 * mapper.
 	 */
-	class_add_devmap_function(&class_list, cli);
-	
-	free(devmap_pathname);
+	class_add_loc_function(&class_list, cli);
+	
+	free(loc_pathname);
 }
 
@@ -381,6 +381,6 @@
 	dev_class_info_t *class_info = add_function_to_class(fun, cl, NULL);
 	
-	/* Register the device's class alias by devmapper. */
-	devmap_register_class_dev(class_info);
+	/* Register the device's class alias with location service. */
+	loc_register_class_dev(class_info);
 	
 	log_msg(LVL_NOTE, "Function `%s' added to class `%s' as `%s'.",
@@ -659,15 +659,15 @@
 }
 
-/** Function for handling connections from a client forwarded by the device
- * mapper to the device manager. */
-static void devman_connection_devmapper(ipc_callid_t iid, ipc_call_t *icall)
-{
-	devmap_handle_t devmap_handle = IPC_GET_ARG2(*icall);
+/** Function for handling connections from a client forwarded by the location
+ * service to the device manager. */
+static void devman_connection_loc(ipc_callid_t iid, ipc_call_t *icall)
+{
+	service_id_t service_id = IPC_GET_ARG2(*icall);
 	fun_node_t *fun;
 	dev_node_t *dev;
 
-	fun = find_devmap_tree_function(&device_tree, devmap_handle);
+	fun = find_loc_tree_function(&device_tree, service_id);
 	if (fun == NULL)
-		fun = find_devmap_class_function(&class_list, devmap_handle);
+		fun = find_loc_class_function(&class_list, service_id);
 	
 	if (fun == NULL || fun->dev->drv == NULL) {
@@ -689,5 +689,5 @@
 	
 	log_msg(LVL_DEBUG,
-	    "Forwarding devmapper request for `%s' function to driver `%s'.",
+	    "Forwarding loc service request for `%s' function to driver `%s'.",
 	    fun->pathname, dev->drv->name);
 }
@@ -708,7 +708,7 @@
 		devman_forward(iid, icall, false);
 		break;
-	case DEVMAN_CONNECT_FROM_DEVMAP:
-		/* Someone connected through devmap node. */
-		devman_connection_devmapper(iid, icall);
+	case DEVMAN_CONNECT_FROM_LOC:
+		/* Someone connected through loc node. */
+		devman_connection_loc(iid, icall);
 		break;
 	case DEVMAN_CONNECT_TO_PARENTS_DEVICE:
@@ -746,10 +746,10 @@
 	
 	/*
-	 * !!! devman_connection ... as the device manager is not a real devmap
+	 * !!! devman_connection ... as the device manager is not a real loc
 	 * driver (it uses a completely different ipc protocol than an ordinary
 	 * devmap driver) forwarding a connection from client to the devman by
 	 * devmapper would not work.
 	 */
-	devmap_driver_register(NAME, devman_connection);
+	loc_server_register(NAME, devman_connection);
 	
 	return true;
@@ -333,28 +333,28 @@
 	
 	/*
-	 * Register the device by the device mapper and remember its devmap
-	 * handle.
+	 * Register the device with location service and remember its
+	 * service ID.
 	 */
@@ -333,28 +333,28 @@
 	
 	/*
-	 * Add device to the hash map of class devices registered by device
-	 * mapper.
+	 * Add device to the hash map of class devices registered with
+	 * location service.
 	 */
@@ -746,10 +746,10 @@
 	 * driver (it uses a completely different ipc protocol than an ordinary
-	 * devmap driver) forwarding a connection from client to the devman by
-	 * devmapper would not work.
+	 * loc driver) forwarding a connection from client to the devman by
+	 * location service would not work.
 	 */
